==> openshift-model-4.11.2-sources.jar: annotations/io/fabric8/openshift/api/model/TLSProfileSpecFluent.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.StringBuffer;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface TLSProfileSpecFluent<A extends TLSProfileSpecFluent<A>> extends Fluent<A>{


    public A addToCiphers(int index,String item);
    public A setToCiphers(int index,String item);
    public A addToCiphers(String... items);
    public A addAllToCiphers(Collection<String> items);
    public A removeFromCiphers(String... items);
    public A removeAllFromCiphers(Collection<String> items);
    public List<String> getCiphers();
    public String getCipher(int index);
    public String getFirstCipher();
    public String getLastCipher();
    public String getMatchingCipher(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public Boolean hasMatchingCipher(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public A withCiphers(List<String> ciphers);
    public A withCiphers(String... ciphers);
    public Boolean hasCiphers();
    public A addNewCipher(String arg1);
    public A addNewCipher(StringBuilder arg1);
    public A addNewCipher(StringBuffer arg1);
    public String getMinTLSVersion();
    public A withMinTLSVersion(String minTLSVersion);
    public Boolean hasMinTLSVersion();
    public A withNewMinTLSVersion(String arg1);
    public A withNewMinTLSVersion(StringBuilder arg1);
    public A withNewMinTLSVersion(StringBuffer arg1);



}

==> openshift-model-5.0.1-sources.jar: annotations/io/fabric8/openshift/api/model/TLSProfileSpecFluent.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface TLSProfileSpecFluent<A extends TLSProfileSpecFluent<A>> extends Fluent<A> {


    public A addToCiphers(int index,String item);
    public A setToCiphers(int index,String item);
    public A addToCiphers(String... items);
    public A addAllToCiphers(Collection<String> items);
    public A removeFromCiphers(String... items);
    public A removeAllFromCiphers(Collection<String> items);
    public List<String> getCiphers();
    public String getCipher(int index);
    public String getFirstCipher();
    public String getLastCipher();
    public String getMatchingCipher(Predicate<String> predicate);
    public Boolean hasMatchingCipher(Predicate<String> predicate);
    public A withCiphers(List<String> ciphers);
    public A withCiphers(String... ciphers);
    public Boolean hasCiphers();
    public A addNewCipher(String arg1);
    public A addNewCipher(StringBuilder arg1);
    public A addNewCipher(StringBuffer arg1);
    public String getMinTLSVersion();
    public A withMinTLSVersion(String minTLSVersion);
    public Boolean hasMinTLSVersion();
    public A withNewMinTLSVersion(String arg1);
    public A withNewMinTLSVersion(StringBuilder arg1);
    public A withNewMinTLSVersion(StringBuffer arg1);
}
